# Table of Contents

- [configure-data-quality-controls](<./configure-data-quality-controls.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configure Data Quality Controls](<./Configure-Data-Quality-Controls.md>)
  - [Ensure Data Integrity with the Quality Seal](<./Configure-Data-Quality-Controls/Ensure-Data-Integrity-with-the-Quality-Seal.md>)
  - [Define Mandatory Attributes for Fact Sheets](<./Configure-Data-Quality-Controls/Define-Mandatory-Attributes-for-Fact-Sheets.md>)
  - [Track Data Completeness with the Completion Score](<./Configure-Data-Quality-Controls/Track-Data-Completeness-with-the-Completion-Score.md>)
